==> polls-v1.4.1.zip: polls/messages/cs/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Poznámka:</strong> Výsledek je skrytý, dokud hlasování neuzavře moderátor.',
    'Access denied!' => 'Přístup odepřen!',
    'Add answer...' => 'Vložit odpověď...',
    'Again? ;Weary;' => 'Znovu? ;Unavený;',
    'Allows the user to create polls' => 'Povolit uživateli vytvářet ankety',
    'Allows to start polls.' => 'Povolit vytváření anket.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonymní hlasování?',
    'Anonymous poll!' => 'Anonymní anketa!',
    'Answers' => 'Odpovědi',
    'At least one answer is required' => 'Je vyžadována alespoň jedna odpověď',
    'Cancel' => 'Zrušit',
    'Close Poll' => 'Dokončit anketu',
    'Closed' => 'Uzavřeno',
    'Club A Steakhouse' => 'Steakhouse',
    'Could not load poll!' => 'Nebylo možné načíst anketu!',
    'Create poll' => 'Vytvořit anketu',
    'Description' => 'Popis',
    'Display answers in random order?' => 'Zobrazit odpovědi náhodně?',
    'Edit answer (empty answers will be removed)...' => 'Upravit odpovědi (prázdné odpovědi budou smazány)...',
    'Edit your poll question...' => 'Upravit otázku Vaší ankety...',
    'Hide results until poll is closed?' => 'Skrýt výsledky, dokud nebude hlasování uzavřeno?',
    'Invalid answer!' => 'Neplatná odpověď!',
    'Location of the next meeting' => 'Místo příští schůzky',
    'Multiple answers per user' => 'Více odpovědí na jednoho uživatele',
    'Pisillo Italian Panini' => 'Pisillo italské Panini',
    'Please specify at least {min} answers!' => 'Minimální počet možných odpovědí je {min}!',
    'Poll' => 'Anketa',
    'Polls' => 'Ankety',
    'Question' => 'Otázka',
    'Reopen Poll' => 'Znovu otevřít anketu',
    'Reset my vote' => 'Zrušit mé hlasování',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Právě teď jsme ve fázi plánování pro další setkání a my bychom rádi věděli, kam byste chtěli jít?',
    'Save' => 'Uložit',
    'To Daniel' => 'Danielovi',
    'Users voted for: <strong>{answer}</strong>' => 'Uživatelé, kteří hlasovali pro odpověď: <strong>{answer}</strong>',
    'Vote' => 'Hlasovat',
    'Voting for multiple answers is disabled!' => 'Není možné hlasovat pro více odpovědí!',
    'Whenever someone participates in a poll.' => 'Kdykoli se někdo zúčastní ankety.',
    'Why don\'t we go to Bemelmans Bar?' => 'Proč nejdeme do Bemelmans Bar?',
    'You have insufficient permissions to perform that operation!' => 'Pro tuto operaci nemáte dostatečná oprávnění!',
    'and {count} more vote for this.' => 'a dalších {count} lidí pro to hlasovalo.',
    'votes' => 'hlasů',
    '{userName} answered the {question}.' => 'Uživatel {userName} odpověděl na otázku {question}.',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];

==> polls-v1.4.2.zip: polls/messages/cs/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Poznámka:</strong> Výsledek je skrytý, dokud hlasování neuzavře moderátor.',
    'Access denied!' => 'Přístup odepřen!',
    'Add answer...' => 'Vložit odpověď...',
    'Again? :weary:' => 'Znovu? ;Unavený;',
    'Allows the user to create polls' => 'Povolit uživateli vytvářet ankety',
    'Allows to start polls.' => 'Povolit vytváření anket.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonymní hlasování?',
    'Anonymous poll!' => 'Anonymní anketa!',
    'Answers' => 'Odpovědi',
    'At least one answer is required' => 'Je vyžadována alespoň jedna odpověď',
    'Cancel' => 'Zrušit',
    'Close Poll' => 'Dokončit anketu',
    'Closed' => 'Uzavřeno',
    'Club A Steakhouse' => 'Steakhouse',
    'Could not load poll!' => 'Nebylo možné načíst anketu!',
    'Create poll' => 'Vytvořit anketu',
    'Description' => 'Popis',
    'Display answers in random order?' => 'Zobrazit odpovědi náhodně?',
    'Edit answer (empty answers will be removed)...' => 'Upravit odpovědi (prázdné odpovědi budou smazány)...',
    'Edit your poll question...' => 'Upravit otázku Vaší ankety...',
    'Hide results until poll is closed?' => 'Skrýt výsledky, dokud nebude hlasování uzavřeno?',
    'Invalid answer!' => 'Neplatná odpověď!',
    'Location of the next meeting' => 'Místo příští schůzky',
    'Multiple answers per user' => 'Více odpovědí na jednoho uživatele',
    'Pisillo Italian Panini' => 'Pisillo italské Panini',
    'Please specify at least {min} answers!' => 'Minimální počet možných odpovědí je {min}!',
    'Poll' => 'Anketa',
    'Polls' => 'Ankety',
    'Question' => 'Otázka',
    'Reopen Poll' => 'Znovu otevřít anketu',
    'Reset my vote' => 'Zrušit mé hlasování',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Právě teď jsme ve fázi plánování pro další setkání a my bychom rádi věděli, kam byste chtěli jít?',
    'Save' => 'Uložit',
    'To Daniel' => 'Danielovi',
    'Users voted for: <strong>{answer}</strong>' => 'Uživatelé, kteří hlasovali pro odpověď: <strong>{answer}</strong>',
    'Vote' => 'Hlasovat',
    'Voting for multiple answers is disabled!' => 'Není možné hlasovat pro více odpovědí!',
    'Whenever someone participates in a poll.' => 'Kdykoli se někdo zúčastní ankety.',
    'Why don\'t we go to Bemelmans Bar?' => 'Proč nejdeme do Bemelmans Bar?',
    'You have insufficient permissions to perform that operation!' => 'Pro tuto operaci nemáte dostatečná oprávnění!',
    'and {count} more vote for this.' => 'a dalších {count} lidí pro to hlasovalo.',
    'votes' => 'hlasů',
    '{userName} answered the {question}.' => 'Uživatel {userName} odpověděl na otázku {question}.',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];
